@@ -42,12 +42,26 @@ class Globalization:
               "image_bed_changed": "图床已切换",
               "invalid_image_bed": "不是合法的图床",
               "new_token_input": "请输入新的访问令牌",
-              "token_changed_successfully":"已成功更新访问令牌",
-              "no_find_local_image":"没有找到可以处理的图片",
-              "index_file_created":"已成功生成网络图床索引文件：markdown_img_index.md",
-              "image_web_configs_changed":"图床配置已更新",
-              "input_error_and_hint":"输入的值{}不合法，请阅读帮助文档。",
-              "related_configs_changed":"相关配置已更新",
+              "token_changed_successfully": "已成功更新访问令牌",
+              "no_find_local_image": "没有找到可以处理的图片",
+              "index_file_created": "已成功生成网络图床索引文件：markdown_img_index.md",
+              "image_web_configs_changed": "图床配置已更新",
+              "input_error_and_hint": "输入的值{}不合法，请阅读帮助文档。",
+              "related_configs_changed": "相关配置已更新",
+              "qiniu_info_saved": "七牛云的相关信息已保存，请重新运行程序",
+              "qiniu_info_required": "缺少七牛云的相关配置，请按提示输入",
+              "qiniu_access_key_input": "请输入七牛云存储的access_key",
+              "qiniu_secret_key_input": "请输入七牛云存储的secret_key",
+              "qiniu_dns_domain_input": "请输入七牛云DNS绑定的域名",
+              "qiniu_bucket_name_input": "请输入七牛云存储的名称",
+              "qiniu_new_access_key_input": "请输入新的七牛云存储access_key",
+              "qiniu_new_secret_key_input": "请输入新的七牛云存储secret_key",
+              "qiniu_new_dns_domain_input": "请输入新的七牛云DNS绑定的域名",
+              "qiniu_new_bucket_name_input": "请输入新的七牛云存储名称",
+              "qiniu_access_key": "七牛云存储access_key",
+              "qiniu_secret_key": "七牛云存储secret_key",
+              "qiniu_dns_domain": "七牛云DNS绑定的域名",
+              "qiniu_bucket_name": "七牛云存储的名称",
               }
     textEN = {"program_version": "program version",
               "colon": ":",
@@ -88,12 +102,26 @@ class Globalization:
               "image_bed_changed": "The image bed has been switched",
               "invalid_image_bed": "Not a legal image bed",
               "new_token_input": "Please enter a new access token",
-              "token_changed_successfully":"Access token has been successfully updated",
-              "no_find_local_image":"No images found that can be processed",
-              "index_file_created":"The webbed index file has been successfully generated: markdown_img_index.md",
-              "image_web_configs_changed":"The image bed configuration has been updated",
-              "input_error_and_hint":"The entered value {} is not legal, please read the help documentation.",
-              "related_configs_changed":"Related configurations have been updated",
+              "token_changed_successfully": "Access token has been successfully updated",
+              "no_find_local_image": "No images found that can be processed",
+              "index_file_created": "The webbed index file has been successfully generated: markdown_img_index.md",
+              "image_web_configs_changed": "The image bed configuration has been updated",
+              "input_error_and_hint": "The entered value {} is not legal, please read the help documentation.",
+              "related_configs_changed": "Related configurations have been updated",
+              "qiniu_info_saved": "The information about the qiniu cloud has been saved, please re-run the program",
+              "qiniu_info_required": "Missing configuration of the qiniu cloud, please follow the prompts to enter",
+              "qiniu_access_key_input": "Please enter the access_key of the qiniu cloud storage",
+              "qiniu_secret_key_input": "Please enter the secret_key of the qiniu cloud storage",
+              "qiniu_dns_domain_input": "Please enter the domain name of the DNS binding of the qiniu cloud",
+              "qiniu_bucket_name_input": "Please enter the name of the qiniu cloud storage",
+              "qiniu_new_access_key_input": "Please enter the new qiniu cloud storage access_key",
+              "qiniu_new_secret_key_input": "Please enter the new qiniu cloud storage secret_key",
+              "qiniu_new_dns_domain_input": "Please enter the domain name of the new qiniu cloud DNS binding",
+              "qiniu_new_bucket_name_input": "Please enter a new name for the qiniu cloud storage",
+              "qiniu_access_key": "Qiniu Cloud Storage access_key",
+              "qiniu_secret_key": "Qiniu Cloud Storage secret_key",
+              "qiniu_dns_domain": "The domain of Qiniu Cloud DNS bunding",
+              "qiniu_bucket_name": "Qiniu Cloud Storage name",
               }
 
     def __init__(self) -> None:
