@@ -1,3 +1,4 @@
+from qiniu import config
 from .globalization import Globalization
 from .config import Config
 import os
@@ -175,6 +176,21 @@ class Main():
             print(self.globalization.getText("tencent_oss_info_saved"))
         elif userExp.getErrorCode() == UserException.CODE_ERROR_INPUT:
             print(userExp.getErrorMsg())
+        elif userExp.getErrorCode() == UserException.CODE_NO_QINIU_INFO:
+            qiniuInfo = {}
+            print("{}{}".format(self.globalization.getText("qiniu_info_required"),
+                                self.globalization.getText("colon")))
+            qiniuInfo[Config.QINIU_INFO_ACCESS_KEY] = input("{}{}".format(self.globalization.getText("qiniu_access_key_input"),
+                                                                          self.globalization.getText("colon")))
+            qiniuInfo[Config.QINIU_INFO_SECRET_KEY] = input("{}{}".format(self.globalization.getText("qiniu_secret_key_input"),
+                                                                          self.globalization.getText("colon")))
+            qiniuInfo[Config.QINIU_INFO_DNS_DOMAIN] = input("{}{}".format(self.globalization.getText("qiniu_dns_domain_input"),
+                                                                          self.globalization.getText("colon")))
+            qiniuInfo[Config.QINIU_INFO_BUCKET_NAME] = input("{}{}".format(self.globalization.getText("qiniu_bucket_name_input"),
+                                                                           self.globalization.getText("colon")))
+            sysConfig.setConfigParam(Config.PARAM_QINIU_INFO, qiniuInfo)
+            sysConfig.writeMainConfig()
+            print(self.globalization.getText("qiniu_info_saved"))
         else:
             print(self.globalization.getText("undefined_error_info"))
         exit()
@@ -251,7 +267,7 @@ class Main():
 
     def changeImgService(self, selectedService):
         supportedService = {'smms', 'ali', 'rruu',
-                            'vimcn', 'yujian', 'ali2', 'qcloud'}
+                            'vimcn', 'yujian', 'ali2', 'qcloud', 'qiniu'}
         if selectedService not in supportedService:
             print(self.globalization.getText(
                 "not_support_img_service"), selectedService)
@@ -275,6 +291,9 @@ class Main():
         elif selectedService == 'qcloud':
             sysConfig.setConfigParam(
                 Config.PARAM_IMG_SERVICE, Config.IMG_SERVICE_QCLOUD)
+        elif selectedService == 'qiniu':
+            sysConfig.setConfigParam(
+                Config.PARAM_IMG_SERVICE, Config.IMG_SERVICE_QINIU)
         else:
             sysConfig.setConfigParam(
                 Config.PARAM_IMG_SERVICE, Config.IMG_SERVICE_SMMS)
@@ -283,23 +302,12 @@ class Main():
         return True
 
     def changeToken(self, imgService):
-        tokenImgServices = {'rruu', 'smms', 'yujian', 'qcloud'}
+        tokenImgServices = {'rruu', 'smms', 'yujian', 'qcloud', 'qiniu'}
         if imgService not in tokenImgServices:
             print(self.globalization.getText("invalid_image_bed"), imgService)
             return False
         sysConfig = Config()
-        if imgService != 'qcloud':
-            token = input("{}{}".format(self.globalization.getText("new_token_input"),
-                                        self.globalization.getText("colon")))
-            if imgService == 'rruu':
-                sysConfig.setConfigParam(Config.PARAM_RRUU_TOKEN, token)
-            elif imgService == 'smms':
-                sysConfig.setConfigParam(Config.PARAM_SMMS_TOKEN, token)
-            elif imgService == 'yujian':
-                sysConfig.setConfigParam(Config.PARAM_YUJIAN_TOKEN, token)
-            else:
-                pass
-        else:
+        if imgService == 'qcloud':
             qcloudInfo = {}
             qcloudInfo[Config.QCLOUD_INFO_SECRET_ID] = input("{}{}".format(self.globalization.getText("new_secret_id_input"),
                                                                            self.globalization.getText("colon")))
@@ -313,6 +321,28 @@ class Main():
             qcloudInfo[Config.QCLOUD_INFO_DES_DIR] = input("{}{}".format(self.globalization.getText("new_storage_dir_input"),
                                                                          self.globalization.getText("colon")))
             sysConfig.setConfigParam(Config.PARAM_QCLOUD_INFO, qcloudInfo)
+        elif imgService == 'qiniu':
+            qiniuInfo = {}
+            qiniuInfo[Config.QINIU_INFO_ACCESS_KEY] = input("{}{}".format(self.globalization.getText(
+                "qiniu_new_access_key_input"), self.globalization.getText("colon")))
+            qiniuInfo[Config.QINIU_INFO_SECRET_KEY] = input("{}{}".format(self.globalization.getText(
+                "qiniu_new_secret_key_input"), self.globalization.getText("colon")))
+            qiniuInfo[Config.QINIU_INFO_DNS_DOMAIN] = input("{}{}".format(self.globalization.getText(
+                "qiniu_new_dns_domain_input"), self.globalization.getText("colon")))
+            qiniuInfo[Config.QINIU_INFO_BUCKET_NAME] = input("{}{}".format(self.globalization.getText(
+                "qiniu_new_bucket_name_input"), self.globalization.getText("colon")))
+            sysConfig.setConfigParam(Config.PARAM_QINIU_INFO, qiniuInfo)
+        else:
+            token = input("{}{}".format(self.globalization.getText("new_token_input"),
+                                        self.globalization.getText("colon")))
+            if imgService == 'rruu':
+                sysConfig.setConfigParam(Config.PARAM_RRUU_TOKEN, token)
+            elif imgService == 'smms':
+                sysConfig.setConfigParam(Config.PARAM_SMMS_TOKEN, token)
+            elif imgService == 'yujian':
+                sysConfig.setConfigParam(Config.PARAM_YUJIAN_TOKEN, token)
+            else:
+                pass
         sysConfig.writeMainConfig()
         print(self.globalization.getText("token_changed_successfully"))
         return True
@@ -419,18 +449,7 @@ class Main():
                 "whether_to_use_url_encoding"), self.globalization.getText("colon"), urlEncodeModeText))
             print("{}{}".format(self.globalization.getText(
                 "image_bed_configs"), self.globalization.getText("colon")))
-            if imgService != Config.IMG_SERVICE_QCLOUD:
-                if imgService == Config.IMG_SERVICE_ALI or imgService == Config.IMG_SERVICE_YUJIAN:
-                    token = sysConfig.getYujianToken()
-                elif imgService == Config.IMG_SERVICE_ALI2 or imgService == Config.IMG_SERVICE_RRUU:
-                    token = sysConfig.getRruuToken()
-                elif imgService == Config.IMG_SERVICE_SMMS:
-                    token = sysConfig.getSmmsToken()
-                else:
-                    token = ''
-                print("\t{}{}{}".format(self.globalization.getText(
-                    "acess_token"), self.globalization.getText("colon"), token))
-            else:
+            if imgService == Config.IMG_SERVICE_QCLOUD:
                 # 显示腾讯云相关配置信息
                 qcloudInfo = sysConfig.getQCloudInfo()
                 print("\t{}{}{}".format(self.globalization.getText("storage_bucket"),
@@ -444,5 +463,27 @@ class Main():
                 print("\t{}{}{}".format(self.globalization.getText("storage_directory"),
                                         self.globalization.getText("colon"),
                                         qcloudInfo[Config.QCLOUD_INFO_DES_DIR]))
+            elif imgService == Config.IMG_SERVICE_QINIU:
+                # 显示七牛云相关配置信息
+                qiniuInfo = sysConfig.getQiniuInfo()
+                print("\t{}{}{}".format(self.globalization.getText("qiniu_access_key"),
+                      self.globalization.getText("colon"), qiniuInfo[Config.QINIU_INFO_ACCESS_KEY]))
+                print("\t{}{}{}".format(self.globalization.getText("qiniu_secret_key"),
+                      self.globalization.getText("colon"), qiniuInfo[Config.QINIU_INFO_SECRET_KEY]))
+                print("\t{}{}{}".format(self.globalization.getText("qiniu_dns_domain"),
+                      self.globalization.getText("colon"), qiniuInfo[Config.QINIU_INFO_DNS_DOMAIN]))
+                print("\t{}{}{}".format(self.globalization.getText("qiniu_bucket_name"),
+                      self.globalization.getText("colon"), qiniuInfo[Config.QINIU_INFO_BUCKET_NAME]))
+            else:
+                if imgService == Config.IMG_SERVICE_ALI or imgService == Config.IMG_SERVICE_YUJIAN:
+                    token = sysConfig.getYujianToken()
+                elif imgService == Config.IMG_SERVICE_ALI2 or imgService == Config.IMG_SERVICE_RRUU:
+                    token = sysConfig.getRruuToken()
+                elif imgService == Config.IMG_SERVICE_SMMS:
+                    token = sysConfig.getSmmsToken()
+                else:
+                    token = ''
+                print("\t{}{}{}".format(self.globalization.getText(
+                    "acess_token"), self.globalization.getText("colon"), token))
         except UserException as e:
             self.dealUserException(e)
